//! Tests auto-converted from "sass-spec/spec/css/supports/syntax"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("syntax")
}

mod anything;

mod calculations;

mod declaration;

mod function;

mod lone_interpolation;

mod operator;
