//! Tests auto-converted from "sass-spec/spec/libsass/variable-scoping/blead-global"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("blead-global")
}

mod expanding;

mod functional;
