//! Tests auto-converted from "sass-spec/spec/core_functions/meta/inspect/list"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("list")
}

mod bracketed;

mod comma;

mod empty;

mod nested;

mod single;

mod space;
