//! Tests auto-converted from "sass-spec/spec/directives/use/css/order"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("order")
}

mod use_and_import;

mod use_only;
