//! Tests auto-converted from "sass-spec/spec/non_conformant/parser/interpolate/44_selector/todo_single_escape"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("todo_single_escape")
}

mod t11_escaped_interpolated_value;

mod t21_escaped_interpolated_variable;

mod t31_escaped_literal;
