//! Tests auto-converted from "sass-spec/spec/libsass-todo-tests/errors/unicode/invalid"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("invalid")
}

// Ignoring "after", tests with expected error not implemented yet.

// Ignoring "before", tests with expected error not implemented yet.
