//! Tests auto-converted from "sass-spec/spec/core_functions/global"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("global")
}

mod color;

mod list;

mod map;

mod math;

mod meta;

mod selector;

mod string;
