//! Tests auto-converted from "sass-spec/spec/non_conformant/sass_4_0/color_arithmetic/addition"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("addition")
}

mod color_color;

mod color_number;

mod number_color;
