//! Tests auto-converted from "sass-spec/spec/non_conformant/errors/import/file/mixin/control-else"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("control-else")
}

mod inside;

mod outside;
