//! Tests auto-converted from "sass-spec/spec/parser/indentation.hrx"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("indentation")
}

mod empty_line {
    #[allow(unused)]
    use super::runner;
}
mod error {
    #[allow(unused)]
    use super::runner;

    mod mixed_syntax {
        #[allow(unused)]
        use super::runner;
    }
}
