//! Tests auto-converted from "sass-spec/spec/non_conformant/scss/media"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("media")
}

mod interpolated;

mod nesting;

mod script_features;
