//! Tests auto-converted from "sass-spec/spec/non_conformant/parser/operations/subtract/numbers"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("numbers")
}

mod pairs;
