//! Tests auto-converted from "sass-spec/spec/non_conformant/errors/import/miss/loop"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("loop")
}

mod each;

mod test_for;

mod test_while;
