//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_1210"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("issue_1210")
}

mod ampersand;

mod basic;

mod extend;

mod keyframes;

mod media;

mod nested;

mod with_without;
