//! Tests auto-converted from "sass-spec/spec/libsass/error-directive-nested"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("error-directive-nested")
}

mod function;

mod inline;

mod mixin;
