//! Tests auto-converted from "sass-spec/spec/non_conformant/sass/semicolon"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("semicolon")
}

mod at_rule;

mod content;

mod debug;

mod declaration;

mod error;

mod import;

mod include;

mod test_return;

mod variable;

mod warn;
