//! Tests auto-converted from "sass-spec/spec/values/calculation/calc/error/known_incompatible"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("known_incompatible")
}

mod angle;

mod complex;

mod frequency;

mod length;

mod minus;

mod time;

mod unknown_and_none;
