//! Tests auto-converted from "sass-spec/spec/core_functions/color/invert"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("invert")
}

mod alpha;

mod error;

mod global;

mod legacy;

mod modern;

mod named;

mod number;
