//! Tests auto-converted from "sass-spec/spec/operators"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("operators")
}

mod minus;

mod modulo;

mod plus;

mod slash;
