//! Tests auto-converted from "sass-spec/spec/libsass-todo-issues/issue_2235"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("issue_2235")
}

mod empty;

mod not_empty;
