//! Tests auto-converted from "sass-spec/spec/core_functions/list"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("list")
}

mod append;

mod index;

mod is_bracketed;

mod join;

mod length;

mod nth;

mod separator;

mod set_nth;

mod slash;

mod utils;

mod zip;
