//! Tests auto-converted from "sass-spec/spec/non_conformant/parser/operations"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("operations")
}

mod addition;

mod binary_and_unary;

mod division;

mod logic_eq;

mod logic_ne;

mod subtract;
