//! Tests auto-converted from "sass-spec/spec/non_conformant/parser/interpolate/33_space_list/03_inline_double.hrx"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("03_inline_double")
}

#[test]
fn test() {
    assert_eq!(
        runner().ok(".result {\
             \n  output: #{#{\"[\"\'foo   \'\"]\"    \"bar\"}};\
             \n  output: #{\"[#{\"[\"\'foo   \'\"]\"    \"bar\"}]\"};\
             \n  output: #{\"#{\"[\"\'foo   \'\"]\"    \"bar\"}\"};\
             \n  output: #{\'#{\"[\"\'foo   \'\"]\"    \"bar\"}\'};\
             \n  output: #{\"[\'#{\"[\"\'foo   \'\"]\"    \"bar\"}\']\"};\
             \n}\n"),
        ".result {\
         \n  output: [ foo    ] bar;\
         \n  output: [[ foo    ] bar];\
         \n  output: [ foo    ] bar;\
         \n  output: [ foo    ] bar;\
         \n  output: [\'[ foo    ] bar\'];\
         \n}\n"
    );
}
