//! Tests auto-converted from "sass-spec/spec/values/numbers/divide/slash_free"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("slash_free")
}

mod argument;

mod test_return;

mod value;

mod variable;
