//! Tests auto-converted from "sass-spec/spec/core_functions/string"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("string")
}

mod index;

mod insert;

mod length;

mod quote;

mod slice;

mod split;

mod to_lower_case;

mod to_upper_case;

mod unique_id;

mod unquote;
