//! Tests auto-converted from "sass-spec/spec/non_conformant/nesting"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("nesting")
}

mod not;

mod parent_with_newline;
