//! Tests auto-converted from "sass-spec/spec/libsass/selectors/variables/nested"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("nested")
}

mod bare;

mod interpolated;
