//! Tests auto-converted from "sass-spec/spec/libsass-todo-issues"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("libsass-todo-issues")
}

mod issue_1026;

mod issue_1096;

mod issue_1694;

mod issue_1732;

mod issue_1763;

mod issue_1798;

mod issue_1801;

mod issue_2016;

mod issue_2023;

mod issue_2051;

mod issue_2096;

// Ignoring "issue_221260.hrx", not expected to work yet.

// Ignoring "issue_221262.hrx", not expected to work yet.

// Ignoring "issue_221264.hrx", not expected to work yet.

// Ignoring "issue_221267", tests with expected error not implemented yet.

// Ignoring "issue_221286", tests with expected error not implemented yet.

// Ignoring "issue_221292.hrx", not expected to work yet.

mod issue_2235;

mod issue_2295;

mod issue_238764;

// Ignoring "issue_245442", tests with expected error not implemented yet.

// Ignoring "issue_245446", tests with expected error not implemented yet.

mod issue_2818;
