//! Tests auto-converted from "sass-spec/spec/core_functions/selector/extend"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("extend")
}

mod complex;

mod error;

mod format;

mod list;

mod named;

mod no_op;

mod simple;
