//! Tests auto-converted from "sass-spec/spec/css/plain"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("plain")
}

mod boolean_operations;

mod calculation;

mod custom_properties;

mod error;

mod extend;

mod functions;

mod hacks;

mod import;

mod media;

mod null;

mod single_equals;

mod slash;

mod style_rule;
