//! Tests auto-converted from "sass-spec/spec/non_conformant/mixin/content/arguments"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("arguments")
}

mod error;

mod none;

mod passing;

mod receiving;

mod scope;

mod weird_syntax;
