//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_1169/error"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("error")
}

mod color;

mod functioncall;

mod interpolate;

mod simple;
