/* Some raw css for testing. */
@media screen and (min-width: 42em) {
    /* Do this for wide viewports */
    div.something {
        display: flex;
    }
}
@font-face {
    font-family: Cocanut;
    font-style: regular;
    font-weight: regular;
    src: local("Cocanut.otf"), url("cocanut.otf");
}
#foo {
    /* Draw a border on this. */
    border: solid 1px black;
}
