//! Tests auto-converted from "sass-spec/spec/core_functions/color/oklab"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("oklab")
}

mod alpha;

mod error;

mod no_alpha;

mod special_functions;
