//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_550/variable"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("variable")
}

mod dimension;

mod number;

mod percent;
