//! Tests auto-converted from "sass-spec/spec/libsass/color-functions/rgb/rgba"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("rgba")
}

mod a;

mod b;

mod g;

mod r;
