//! Tests auto-converted from "sass-spec/spec/values/calculation"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("calculation")
}

mod abs;

mod acos;

mod asin;

mod atan;

mod atan2;

mod calc;

mod calc_size;

mod clamp;

mod cos;

mod exp;

mod hypot;

mod log;

mod max;

mod min;

mod test_mod;

mod pow;

mod rem;

mod round;

mod sign;

mod sin;

mod sqrt;

mod tan;
