//! Tests auto-converted from "sass-spec/spec/non_conformant/errors/unicode/report"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("report")
}

mod after;

mod before;
