//! Tests auto-converted from "sass-spec/spec/core_functions/color/hwb/three_args/w3c"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("w3c")
}

mod blue_magentas;

mod blues;

mod cyan_blues;

mod cyans;

mod green_cyans;

mod greens;

mod magenta_reds;

mod magentas;

mod oranges;

mod reds;

mod yellow_greens;

mod yellows;
