//! Tests auto-converted from "sass-spec/spec/core_functions/selector/unify"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("unify")
}

mod chooses_superselector;

mod complex;

mod compound;

mod error;

mod format;

mod simple;
