//! Tests auto-converted from "sass-spec/spec/non_conformant/parser/malformed_expressions"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("malformed_expressions")
}

mod at_debug;

mod at_error;

mod at_warn;
