//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_659"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("issue_659")
}

mod issue_659;

mod sass_script;

mod test_static;
