//! Tests auto-converted from "sass-spec/spec/libsass/selectors/variables"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("variables")
}

mod multiple;

mod nested;

mod single;
