//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_1432"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("issue_1432")
}

mod selector_extend;

mod selector_nest;

mod selector_replace;

mod selector_unify;

mod simple_selectors;
