//! Tests auto-converted from "sass-spec/spec/values/numbers/units/multiple"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("multiple")
}

mod divide_by_multiple_denominators;

mod divide_by_multiple_numerators;

mod division_cancels_both;

mod division_cancels_compatible;

mod division_cancels_denominator;

mod division_cancels_denominator_twice;

mod division_cancels_numerator;

mod division_cancels_numerator_twice;

mod division_cancels_unknown;

mod multiple_denominators;

mod multiple_numerators;

mod multiplication_cancels_both;

mod multiplication_cancels_compatible;

mod multiplication_cancels_denominator;

mod multiplication_cancels_denominator_twice;

mod multiplication_cancels_numerator;

mod multiplication_cancels_numerator_twice;

mod multiplication_cancels_unknown;
