//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_1732/valid"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("valid")
}

mod directive;

mod keyframe;

mod mixin_call;

mod mixin_def;

mod propset;

mod ruleset;
