//! Tests auto-converted from "sass-spec/spec/css/supports"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("supports")
}

mod comment;

mod error;

mod nesting;

mod syntax;
