//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_1550"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("issue_1550")
}

mod each_embedded;

mod for_embedded;

mod if_embedded;

mod mixin_embedded;

mod while_embedded;
