//! Tests auto-converted from "sass-spec/spec/libsass/color-functions/other/change-color"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("change-color")
}

mod a;

mod b;

mod g;

mod h;

mod l;

mod r;

mod s;
