//! Tests auto-converted from "sass-spec/spec/values/colors/alpha_hex"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("alpha_hex").set_precision(10)
}

mod initial_digit;

mod initial_letter;
