//! Tests auto-converted from "sass-spec/spec/libsass/base-level-parent/imported"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("imported")
}

mod at_root_alone_itpl;

mod at_root_alone;

mod at_root_postfix_itpl;

mod at_root_postfix;

mod at_root_prefix_itpl;

mod at_root_prefix;

mod basic_alone_itpl;

mod basic_alone;

mod basic_postfix_itpl;

mod basic_postfix;

mod basic_prefix_itpl;

mod basic_prefix;
