//! Tests auto-converted from "sass-spec/spec/css/selector/combinator"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("combinator")
}

mod has;

mod is;

mod leading;

mod middle;

mod only_one_bogus;

mod selector_pseudo;

mod trailing;
