//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_1803"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("issue_1803")
}

mod nested;

mod shallow;
