//! Tests auto-converted from "sass-spec/spec/non_conformant/errors/fn-debug"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("fn-debug")
}

mod property;

mod ruleset;

mod simple;
