//! Tests auto-converted from "sass-spec/spec/directives/forward"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("forward")
}

mod comment;

mod css;

mod error;

mod escaped;

mod extend;

mod member;

mod with;
