//! Tests auto-converted from "sass-spec/spec/libsass-todo-issues/issue_1694"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("issue_1694")
}

mod quoted_right_dbl_paren;

mod quoted_right_paren;
