//! Tests auto-converted from "sass-spec/spec/libsass/precision"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("precision")
}

mod default;

mod higher;

mod lower;
