//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_1243"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("issue_1243")
}

mod at_rule;

mod comma_list;

mod debug;

mod import;

mod include;

mod space_list;

mod warning;
