//! Tests auto-converted from "sass-spec/spec/core_functions/selector/is_superselector"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("is_superselector")
}

mod complex;

mod compound;

mod error;

mod input;

mod list;

mod named;

mod simple;
