//! Tests auto-converted from "sass-spec/spec/libsass/selector-functions"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("selector-functions")
}

mod selector_length;

mod simple_selector;
