//! Tests auto-converted from "sass-spec/spec/parser"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("parser")
}

mod indentation;

mod operator_precedence;

mod selector;
