//! Tests auto-converted from "sass-spec/spec/values/calculation/calc"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("calc")
}

mod constant;

mod error;

mod no_operator;

mod operator;

mod parens;

mod simplify;

mod space;
