//! Tests auto-converted from "sass-spec/spec/core_functions/selector/nest"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("nest")
}

mod combinator;

mod error;

mod format;

mod list;

mod many_args;

mod one_arg;

mod parent;
