//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_2156"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("issue_2156")
}

mod debug;

mod error;

mod warn;
