//! Tests auto-converted from "sass-spec/spec/core_functions/selector/unify/simple/type"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("type")
}

mod and_type;

mod and_universal;
