//! Tests auto-converted from "sass-spec/spec/core_functions/map"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("map")
}

mod deep_merge;

mod deep_remove;

mod get;

mod has_key;

mod keys;

mod merge;

mod remove;

mod set;

mod values;
