//! Tests auto-converted from "sass-spec/spec/non_conformant/parser/interpolate"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("interpolate")
}

mod t00_concatenation;

mod t01_literal;

mod t02_double_quoted;

mod t03_single_quoted;

mod t04_space_list_quoted;

mod t05_comma_list_quoted;

mod t06_space_list_complex;

mod t07_comma_list_complex;

mod t10_escaped_backslash;

mod t11_escaped_literal;

mod t12_escaped_double_quoted;

mod t13_escaped_single_quoted;

mod t14_escapes_literal_numbers;

mod t15_escapes_double_quoted_numbers;

mod t16_escapes_single_quoted_numbers;

mod t17_escapes_literal_lowercase;

mod t18_escapes_double_quoted_lowercase;

mod t19_escapes_single_quoted_lowercase;

mod t20_escapes_literal_uppercase;

mod t21_escapes_double_quoted_uppercase;

mod t22_escapes_single_quoted_uppercase;

mod t23_escapes_literal_specials;

mod t24_escapes_double_quoted_specials;

mod t25_escapes_single_quoted_specials;

mod t26_escaped_literal_quotes;

mod t27_escaped_double_quotes;

mod t28_escaped_single_quotes;

mod t29_binary_operation;

mod t30_base_test;

mod t31_schema_simple;

mod t32_comma_list;

mod t33_space_list;

mod t34_mixed_list;

mod t44_selector;
