//! Tests auto-converted from "sass-spec/spec/non_conformant/sass_4_0"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("sass_4_0")
}

mod color_arithmetic;

mod interpolation;
