//! Tests auto-converted from "sass-spec/spec/core_functions/selector/extend/simple"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("simple")
}

mod attribute;

mod class;

mod id;

mod placeholder;

mod pseudo;

mod test_type;

mod universal;
