//! Tests auto-converted from "sass-spec/spec/non_conformant/parser/interpolate/00_concatenation"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("00_concatenation")
}

mod spaced;

mod unspaced;
