//! Tests auto-converted from "sass-spec/spec/non_conformant/parser/interpolate/44_selector"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("44_selector")
}

mod colon_twice_todo;

mod double_escape;

mod todo_single_escape;
