//! Tests auto-converted from "sass-spec/spec/non_conformant/sass"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("sass")
}

mod basic;

mod comment;

mod extend;

mod functions;

mod import;

mod imported;

mod indentation;

mod mixins;

mod pseudo;

mod selectors;

mod semicolon;

mod var_args;
