//! Tests auto-converted from "sass-spec/spec/libsass/base-level-parent"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("base-level-parent")
}

mod imported;

mod nested;

mod root;
