//! Tests auto-converted from "sass-spec/spec/css"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("css")
}

mod blockless_directive_without_semicolon;

mod comment;

mod custom_properties;

mod directive_with_lots_of_whitespace;

mod empty_block_directive;

mod escape;

mod font_face;

mod function_name_identifiers;

mod functions;

mod important;

mod keyframes;

mod media;

mod moz_document;

mod ms_long_filter_syntax;

mod plain;

mod propset;

mod selector;

mod style_rule;

mod supports;

mod unicode_range;

mod unknown_directive;

mod url;
