//! Tests auto-converted from "sass-spec/spec/core_functions/selector/is_superselector/simple/pseudo"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("pseudo")
}

mod arg;

mod no_arg;

mod selector_arg;
