//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_185"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("issue_185")
}

mod hoisting;

mod media_level_4;

mod media_wrapper_selector;

mod merge_no_repeat;

mod mixin;

mod selector_wrapper_media;
