//! Tests auto-converted from "sass-spec/spec/core_functions/meta/get_mixin"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("get_mixin")
}

mod content;

mod different_module;

mod equality;

mod error;

mod same_module;

mod scope;
