//! Tests auto-converted from "sass-spec/spec/css/media/range/from_interpolation.hrx"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("from_interpolation")
}

#[test]
fn test() {
    assert_eq!(
        runner().ok(
            "// Range syntax that\'s generated by interpolation is allowed. This falls out of\
             \n// the general property that CSS media features are parsed as\
             \n// <declaration-value>s.\n\
             \n@media #{\"(100px < width < 500px)\"} {a {interpolation: total}}\
             \n@media (#{\"100px < width < 500px\"}) {a {interpolation: in-parens}}\
             \n@media (#{\"100px < width\"} < 500px) {a {interpolation: left}}\
             \n@media (100px < #{\"width < 500px\"}) {a {interpolation: right}}\n"
        ),
        "@media (100px < width < 500px) {\
         \n  a {\
         \n    interpolation: total;\
         \n  }\
         \n}\
         \n@media (100px < width < 500px) {\
         \n  a {\
         \n    interpolation: in-parens;\
         \n  }\
         \n}\
         \n@media (100px < width < 500px) {\
         \n  a {\
         \n    interpolation: left;\
         \n  }\
         \n}\
         \n@media (100px < width < 500px) {\
         \n  a {\
         \n    interpolation: right;\
         \n  }\
         \n}\n"
    );
}
