//! Tests auto-converted from "sass-spec/spec/core_functions/selector/is_superselector/complex"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("complex")
}

mod adjacent_sibling;

mod bogus;

mod child;

mod descendant;

mod sibling;
