//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_1941"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("issue_1941")
}

mod function_function;

mod function_mixin;

mod mixin_function;

mod mixin_mixin;
