//! Tests auto-converted from "sass-spec/spec/values/calculation/round"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("round")
}

mod error;

mod one_argument;

mod strategy;

mod three_arguments;

mod two_arguments;
