//! Tests auto-converted from "sass-spec/spec/core_functions/selector/extend/simple/pseudo/selector/idempotent"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("idempotent")
}

mod any;

mod current;

mod is;

mod matches;

mod not;

mod nth_child;

mod nth_last_child;

mod prefixed;

mod test_where;
