//! Tests auto-converted from "sass-spec/spec/non_conformant/errors/extend"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("extend")
}

mod placeholder;

mod selector;
