//! Tests auto-converted from "sass-spec/spec/non_conformant/errors/invalid-operation"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("invalid-operation")
}

mod gt;

mod gte;

mod lt;

mod lte;

mod test_mod;

mod plus;

mod sub;

mod times;
