//! Tests auto-converted from "sass-spec/spec/directives/each.hrx"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("each")
}

mod error {
    #[allow(unused)]
    use super::runner;

    mod sass {
        #[allow(unused)]
        use super::runner;

        mod multiline {
            #[allow(unused)]
            use super::runner;
        }
    }
}
mod sass {
    #[allow(unused)]
    use super::runner;
}
