//! Tests auto-converted from "sass-spec/spec/directives/if"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("if")
}

mod comment;

mod error;

mod escaped;

mod sass;
