//! Tests auto-converted from "sass-spec/spec/non_conformant/sass_4_0/color_arithmetic"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("color_arithmetic")
}

mod addition;

mod division;

mod modulo;

mod multiplication;

mod subtraction;
