//! Tests auto-converted from "sass-spec/spec/css/selector"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("selector")
}

mod attribute;

mod combinator;

mod escaping;

mod inline_comments;

mod placeholder;

mod pseudoselector;

mod reference_combinator;

mod slotted;
