//! Tests auto-converted from "sass-spec/spec/libsass/selectors"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("selectors")
}

mod access;

mod function_argument;

mod interpolation;

mod mixin_argument;

mod simple;

mod variables;
