//! Tests auto-converted from "sass-spec/spec/values/lists"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("lists")
}

mod brackets;

mod equality;

mod sass;

mod slash;
