//! Tests auto-converted from "sass-spec/spec/css/media"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("media")
}

mod bubbling;

mod comment;

mod indentation;

mod logic;

mod range;

mod test_type;
