//! Tests auto-converted from "sass-spec/spec/core_functions/color/adjust_hue"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("adjust_hue")
}

mod above_max;

mod alpha;

mod error;

mod fraction;

mod max;

mod middle;

mod min;

mod named;

mod negative;

mod units;
