//! Tests auto-converted from "sass-spec/spec/core_functions/modules/color"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("color")
}

mod adjust;

mod alpha;

mod blue;

mod change;

mod complement;

mod css_overloads;

mod error;

mod green;

mod hue;

mod ie_hex_str;

mod invert;

mod lightness;

mod mix;

mod red;

mod saturation;

mod scale;
