//! Tests auto-converted from "sass-spec/spec/non_conformant/errors/invalid-parent"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("invalid-parent")
}

mod function_in_each;

mod function_in_for;

mod function_in_function;

mod function_in_if;

mod function_in_mixin;

mod function_in_while;

mod mixin_in_each;

mod mixin_in_for;

mod mixin_in_function;

mod mixin_in_if;

mod mixin_in_mixin;

mod mixin_in_while;

mod return_in_mixin;

mod return_in_root;

mod return_in_ruleset;
