//! Tests auto-converted from "sass-spec/spec/values"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("values")
}

mod calculation;

mod colors;

mod identifiers;

mod ids;

mod lists;

mod maps;

mod mixins;

mod numbers;

mod strings;
