//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_2260"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("issue_2260")
}

mod inner_parent_no_compound;

mod inner_parent_with_compound;

mod no_parent_no_compound;

mod no_parent_with_compound;

mod outer_parent_no_compound;

mod outer_parent_with_compound;
