//! Tests auto-converted from "sass-spec/spec/non_conformant/mixin"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("mixin")
}

mod content;

mod environment_locality;

mod error;
