//! Tests auto-converted from "sass-spec/spec/non_conformant/parser/interpolate/44_selector/double_escape"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("double_escape")
}

mod t12_double_escaped_interpolated_value_todo;

mod t22_double_escaped_interpolated_variable;

mod t32_double_escaped_literal;
