//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_1590"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("issue_1590")
}

mod ampersand_against_literal;

mod ampersand_as_expression;

mod quoted_ampersand_does_not_select;
