//! Tests auto-converted from "sass-spec/spec/directives/use/error/syntax"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("syntax")
}

mod after;

mod as_invalid;

mod as_nothing;

mod empty;

mod member;

mod url;

mod with;

mod within;
