//! Tests auto-converted from "sass-spec/spec/non_conformant/errors/fn-varargs"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("fn-varargs")
}

mod at_start;

mod multiple;

mod with_default;

mod with_optional;
