//! Tests auto-converted from "sass-spec/spec/core_functions/color/hsl/three_args/w3c"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("w3c")
}

mod black_to_white_through;

mod blue_to_red;

mod gray_to;

mod green_to_blue;

mod hue;

mod red_to_green;
