//! Tests auto-converted from "sass-spec/spec/core_functions/color"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("color")
}

mod adjust;

mod adjust_color;

mod adjust_hue;

mod alpha;

mod blackness;

mod blue;

mod change;

mod channel;

mod color;

mod complement;

mod darken;

mod desaturate;

mod fade_in;

mod fade_out;

mod grayscale;

mod green;

mod hsl;

mod hsla;

mod hue;

mod hwb;

mod ie_hex_str;

mod invert;

mod is_in_gamut;

mod is_legacy;

mod is_missing;

mod is_powerless;

mod lab;

mod lch;

mod lighten;

mod lightness;

mod mix;

mod oklab;

mod oklch;

mod red;

mod rgb;

mod rgba;

mod same;

mod saturate;

mod saturation;

mod scale;

mod space;

mod to_gamut;

mod to_space;

mod whiteness;
