//! Tests auto-converted from "sass-spec/spec/core_functions/selector"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("selector")
}

mod append;

mod extend;

mod is_superselector;

mod nest;

mod parse;

mod replace;

mod unify;
