//! Tests auto-converted from "sass-spec/spec/non_conformant/parser/arglists/can-end-with-comma"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("can-end-with-comma")
}

mod error_call_1;

mod error_call_2;

mod error_call_3;

mod error_function_1;

mod error_function_2;

mod error_function_3;

mod error_include_1;

mod error_include_2;

mod error_include_3;

mod error_mixin_1;

mod error_mixin_2;

mod error_mixin_3;

mod functions;

mod mixins;
