//! Tests auto-converted from "sass-spec/spec/core_functions/math/atan2"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("atan2")
}

mod arguments;

mod y_infinite;

mod y_non_zero_finite;

mod y_zero;
