//! Tests auto-converted from "sass-spec/spec/css/selector/inline_comments.hrx"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("inline_comments")
}

mod loud {
    #[allow(unused)]
    use super::runner;
}
mod silent {
    #[allow(unused)]
    use super::runner;
}
