//! Tests auto-converted from "sass-spec/spec/non_conformant/extend-tests/104_test_nested_extender_counts_extended_subselectors"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner()
        .with_cwd("104_test_nested_extender_counts_extended_subselectors")
}

mod t104_test_nested_extender_counts_extended_subselectors;
