//! Tests auto-converted from "sass-spec/spec/core_functions/selector/extend/simple/pseudo/selector"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("selector")
}

mod idempotent;

mod test_match;

mod non_idempotent;
