//! Tests auto-converted from "sass-spec/spec/non_conformant/errors/extend/placeholder"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("placeholder")
}

mod missing;

mod optional;

mod simple;
