//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_1739/interpolate"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("interpolate")
}

mod both;

mod left;

mod right;
