//! Tests auto-converted from "sass-spec/spec/non_conformant/errors/import/url/mixin/simple"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("simple")
}

mod inside;

mod outside;
