//! Tests auto-converted from "sass-spec/spec/libsass/color-functions"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("color-functions")
}

mod opacity;

mod other;

mod rgb;

mod saturate;
