//! Tests auto-converted from "sass-spec/spec/core_functions/math"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("math")
}

mod abs;

mod acos;

mod asin;

mod atan;

mod atan2;

mod ceil;

mod clamp;

mod comparable;

mod cos;

mod div;

mod floor;

mod hypot;

mod log;

mod max;

mod min;

mod percentage;

mod pow;

mod random;

mod round;

mod sin;

mod sqrt;

mod tan;

mod unit;

mod unitless;

mod variables;
