//! Tests auto-converted from "sass-spec/spec/non_conformant/sass_4_0/interpolation"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("interpolation")
}

mod after_hyphen;

mod function_name;

mod trailing_non_name_start;
