//! Tests auto-converted from "sass-spec/spec/non_conformant/sass/indentation.hrx"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("indentation")
}

mod different {
    #[allow(unused)]
    use super::runner;
}
mod error {
    #[allow(unused)]
    use super::runner;
}
mod unusual_newlines {
    #[allow(unused)]
    use super::runner;
}
