//! Tests auto-converted from "sass-spec/spec/core_functions/color/change/error"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("error")
}

mod args;

mod bounds;

mod incompatible_channel;

mod mixed_formats;

mod space;

mod test_type;

mod units;
