//! Tests auto-converted from "sass-spec/spec/values/lists/sass.hrx"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("sass")
}

mod error {
    #[allow(unused)]
    use super::runner;

    mod no_parens {
        #[allow(unused)]
        use super::runner;
    }
    mod paren {
        #[allow(unused)]
        use super::runner;
    }
}
mod inline {
    #[allow(unused)]
    use super::runner;
}
