//! Tests auto-converted from "sass-spec/spec/non_conformant/extend-tests/fake-pseudo-element-order"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("fake-pseudo-element-order")
}

mod after;

mod before;

mod first_letter;

mod first_line;
