//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_1527/selector"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("selector")
}

mod first;

mod last;

mod only;
