//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_2023"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("issue_2023")
}

mod id_selector_id;

mod id_selector_nr;

mod pseudo_selector_id;

mod pseudo_selector_nr;
