//! Tests auto-converted from "sass-spec/spec/core_functions/color/to_space/lch"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("lch")
}

mod a98_rgb;

mod display_p3;

mod hsl;

mod hwb;

mod lab;

mod lch;

mod oklab;

mod oklch;

mod prophoto_rgb;

mod rec2020;

mod rgb;

mod srgb;

mod srgb_linear;

mod xyz;

mod xyz_d50;
