//! Tests auto-converted from "sass-spec/spec/libsass-closed-issues/issue_1415"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("issue_1415")
}

mod direct;

mod mixin;

mod variable;
