//! Tests auto-converted from "sass-spec/spec/core_functions/selector/unify/complex/combinators"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("combinators")
}

mod child;

mod initial;

mod multiple;

mod next_sibling;

mod sibling;
