//! Tests auto-converted from "sass-spec/spec/values/numbers/divide"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("divide")
}

mod slash_free;

mod slash_separated;
