//! Tests auto-converted from "sass-spec/spec/css/plain/error/statement"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("statement")
}

mod at_rule;

mod silent_comment;

mod style_rule;
