//! Tests auto-converted from "sass-spec/spec/core_functions/color/is_powerless"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("is_powerless")
}

mod error;

mod hsl;

mod hwb;

mod lab;

mod lch;

mod named;

mod oklab;

mod oklch;

mod space;
