//! Tests auto-converted from "sass-spec/spec/directives/forward/member/import"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("import")
}

mod forward_to_import;

mod import_to_forward;

mod precedence;
