//! Tests auto-converted from "sass-spec/spec/core_functions/meta/inspect"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("inspect")
}

mod boolean;

mod color;

mod error;

mod function;

mod inspect;

mod list;

mod map;

mod mixin;

mod null;

mod number;

mod string;
