//! Tests auto-converted from "sass-spec/spec/non_conformant/scss"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("scss")
}

mod almost_ambiguous_nested_rules_and_declarations;

mod alpha;

mod arglist;

mod backrefs_in_selector_groups;

mod backslash;

mod basic_function;

mod basic_mixins;

mod basic_prop_name_interpolation;

mod basic_selector_interpolation;

mod blimp;

mod block_comment_in_script;

mod cfunc;

mod classes_and_ids;

mod color_output;

mod comment_after_if_directive;

mod composed_args;

mod concat;

mod cons_up;

mod css_basic_scss;

mod css_block_directive_with_semicolon;

mod css_cdo_and_cdc_ignored_at_toplevel;

mod css_crazy_comments;

mod css_empty_declarations;

mod css_empty_rule;

mod css_import_directive;

mod css_invisible_comments;

mod css_property_comments;

mod css_rule_comments;

mod css_selector_comments;

mod css_selector_hacks;

mod css_spaceless_combo_selectors;

mod css_unary_ops;

mod default_args;

mod default_parameters;

mod default_vars_in_default_params;

mod directives_in_propsets;

mod each;

mod each_directive;

mod each_in_functions;

mod for_in_functions;

mod function_names;

mod function_args;

mod functions_and_mixins;

mod functions;

mod guard_assign;

mod hey1;

mod hey2;

// Ignoring "huge.hrx", not expected to work yet.

mod hyphen_interpolated;

mod ie_backslash;

mod ie_functions;

mod if_in_mixin;

mod if_in_propset;

mod test_if;

mod if_directive;

mod imp;

mod important_in_arglist;

mod important;

mod interpolated_selectors;

mod interpolated_strings;

mod interpolation_operators_precedence;

mod interpolation;

mod interpolation_with_bracket_on_next_line;

mod keyword_args_in_functions;

mod lang;

mod line_comment_in_script;

mod long_selector;

mod media;

mod mixin_content_selectors;

mod mixin_content_with_no_block;

mod mixin_content;

mod mixin_with_keyword_args;

mod mixins_with_args;

mod mixins_with_empty_args;

// Ignoring "multiline-var.hrx", not expected to work yet.

mod multiline_var;

mod multiple_operators;

mod namespace_properties;

mod namespace_properties_with_value;

mod negation;

mod nested_extend;

mod nested_namespace_properties;

mod nested_rules;

mod nested_rules_with_declarations;

mod nested_rules_with_fancy_selectors;

mod no_namespace_properties_without_space;

mod null;

mod numbers;

mod one_line_comments;

mod parent_selectors;

mod passing_all_as_keyword_args_in_opposite_order;

mod passing_required_args_as_a_keyword_arg;

mod percentages;

mod placeholder_with_media;

mod placeholder;

mod precision;

mod prop_name_interpolation_after_hyphen;

mod prop_name_only_interpolation;

mod property_interpolation_at_dashes;

mod quotes_in_interpolated_strings;

mod retina_image;

mod sass_script;

mod selector_interpolation_at_attr_beginning;

mod selector_interpolation_at_class_begininng;

mod selector_interpolation_at_id_begininng;

mod selector_interpolation_at_pseudo_begininng;

mod selector_interpolation_in_pseudoclass;

mod several_namespace_properties;

mod simple_inheritance;

mod simple_lists;

mod star_plus_and_parent;

mod strings;

mod url_import;

mod variables;

mod vars;

mod weird_selectors;

mod weird_added_space;

mod test_while;

mod while_directive;

mod while_in_functions;

mod while_without_condition;

mod zero_compression;
