//! Tests auto-converted from "sass-spec/spec/directives/forward/member"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("member")
}

mod test_as;

mod bare;

mod import;

mod shadowed;

mod visibility;
